package envoy.client.ui;

import java.awt.Image;
import java.io.IOException;
import java.util.EnumMap;
import java.util.EnumSet;

import javax.imageio.ImageIO;
import javax.swing.ImageIcon;

/**
 * Project: <strong>envoy-client</strong>
 * File: <strong>IconUtil.java</strong>
 * Created: <strong>16.03.2020</strong>
 *
 * @author Kai S. K. Engelbart
 * @since Envoy v0.1-beta
 */
public class IconUtil {

	private IconUtil() {}

	public static ImageIcon load(String path, int size) throws IOException {
		return new ImageIcon(ImageIO.read(IconUtil.class.getResourceAsStream(path)).getScaledInstance(size, size, Image.SCALE_SMOOTH));
	}

	public static <T extends Enum<T>> EnumMap<T, ImageIcon> loadByEnum(Class<T> enumClass, int size) throws IOException {
		var	icons	= new EnumMap<T, ImageIcon>(enumClass);
		var	path	= "/icons/" + enumClass.getSimpleName().toLowerCase() + "/";
		for (var e : EnumSet.allOf(enumClass))
			icons.put(e, load(path + e.toString().toLowerCase() + ".png", size));
		return icons;
	}
}
